@@ -145,7 +145,7 @@ void SpeedoMeter::updateTime()
 
 char buf[80];char h[3],m[3],s[3];
 if(hour<10)sprintf(h,"0%d",hour);else sprintf(h,"%d",hour);
-if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",hour);
+if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",min);
 if(sec<10)sprintf(s,"0%d",sec);else sprintf(s,"%d",sec);
 
 sprintf(buf,"%s.%s.%s.%d",h,m,s,tensofsec);
